import logging

from flowtrigger.credentials.types import CredentialProviderType, CredentialProvider


def get_credentails(credential_provider_str: str,
                    file_credential_provider_credentials_path: str | None) -> CredentialProvider | None:
  if not credential_provider_str in {item.value for item in CredentialProviderType}:
    logging.error('Invalid credential provider type. %s', credential_provider_str)
    return None
  credentials_type = CredentialProviderType(credential_provider_str)
  if credentials_type == CredentialProviderType.LIBSECRET:
    from flowtrigger.credentials.libsecret import get_libsecret_credential_provider
    return get_libsecret_credential_provider()
  if credentials_type == CredentialProviderType.FILE:
    from flowtrigger.credentials.file import get_file_credentials
    return get_file_credentials(file_credential_provider_credentials_path)
  return None
