import logging

import click

from flowtrigger.commands.credentials import credentials_group
from flowtrigger.commands.trigger import trigger
from flowtrigger.configuration.types import CONFIGURATION_PROVIDER_KEY
from flowtrigger.credentials.intialize import get_credentails
from flowtrigger.credentials.types import CredentialProviderType, CREDENTIAL_PROVIDER_KEY


@click.group()
@click.option('--configuration', show_default=True, default=None, help="Config file")
@click.option('--credential-provider', 'credential_provider_str',
              type=click.Choice([item.value for item in CredentialProviderType]),
              show_default=True, default=CredentialProviderType.LIBSECRET.value, help="Credential provider type")
@click.option('--credentials', 'credentails_file_path', show_default=True, default=None,
              help="Credentials path for file type credential provider")
@click.option('--log-level', show_default=True, default='INFO', help="Logging level",
              callback=lambda _, __, value: value.upper())
@click.pass_context
def cli(ctx: click.Context, configuration: str | None, credential_provider_str: str, credentails_file_path: str | None,
        log_level) -> None:
  ctx.ensure_object(dict)
  log_level_level = logging.getLevelNamesMapping().get(log_level)
  if log_level_level is None:
    click.ClickException(f'Invalid log level. {log_level}')
  logging.basicConfig(level=log_level_level)
  ctx.obj[CONFIGURATION_PROVIDER_KEY] = configuration
  credentials = get_credentails(credential_provider_str, credentails_file_path)
  logging.debug('Credentials provider: %s',
                'None' if credentials is None else credentials.credential_provider_type.value)
  ctx.obj[CREDENTIAL_PROVIDER_KEY] = credentials


def main():
  cli.add_command(credentials_group)
  cli.add_command(trigger)
  cli()
