from git import Repo
from github import Repository
from github.Notification import Notification
from gitlab.v4.objects import Project


class Fork:
  def __init__(self, fork: Project, upstream: Project, repo: Repo):
    self.__fork: Project = fork
    self.__upstream: Project = upstream
    self.__repo: Repo = repo

  @property
  def fork(self) -> Project:
    return self.__fork

  @property
  def upstream(self) -> Project:
    return self.__upstream

  @property
  def repo(self):
    return self.__repo


class RepoRelease:
  def __init__(self, release_id: int, url: str, tag: str, notification: Notification | None = None):
    self.__release_id: int = release_id
    self.__url: str = url
    self.__tag: str = tag
    self.__notification: Notification | None = notification

  @property
  def release_id(self) -> int:
    return self.__release_id

  @property
  def url(self) -> str:
    return self.__url

  @property
  def tag(self) -> str:
    return self.__tag

  @property
  def notification(self) -> Notification | None:
    return self.__notification


class RepoReleases:
  def __init__(self, repo_id: str, repo: Repository):
    self.__repo_id: str = repo_id
    self.__repo: Repository = repo
    self.__releases: list[RepoRelease] = []

  @property
  def repo(self) -> Repository:
    return self.__repo

  @property
  def releases(self) -> list[RepoRelease]:
    return self.__releases

  def add_release(self, release_id: int, url: str, tag: str, notification: Notification | None = None):
    self.__releases.append(RepoRelease(release_id, url, tag, notification))


class Release:
  def __init__(self, repo_id: str, url: str, tag: str, commit_id: str, notification: Notification | None = None):
    self.__repo_id: str = repo_id
    self.__url: str = url
    self.__tag: str = tag
    self.__commit_id: str = commit_id
    self.__notification: Notification | None = notification

  @property
  def repo_id(self) -> str:
    return self.__repo_id

  @property
  def url(self) -> str:
    return self.__url

  @property
  def tag(self) -> str:
    return self.__tag

  @property
  def commit_id(self) -> str:
    return self.__commit_id

  @property
  def notification(self) -> Notification | None:
    return self.__notification
