import os.path
import shutil

from platformdirs import user_cache_dir, user_config_dir

PROJECT_NAME: str = 'flowtrigger'
PROJECT_VERSION: str = 'dev'  # TODO: use custom hook to inject version during build


def get_cache_dir() -> str:
  return user_cache_dir(PROJECT_NAME)


def empty_dir(path: str):
  if not os.path.exists(path):
    return
  for content_name in os.listdir(path):
    content_path = os.path.join(path, content_name)
    if os.path.isfile(content_path) or os.path.islink(content_path):
      os.unlink(content_path)
    elif os.path.isdir(content_path):
      shutil.rmtree(content_path)


def resolve_configuration_file(filename: str | None) -> str | None:
  potential_path = os.path.abspath(filename)
  if os.path.isfile(potential_path):
    return potential_path

  config_dir = user_config_dir(PROJECT_NAME, ensure_exists=True)
  potential_path = os.path.join(config_dir, filename)

  return potential_path if os.path.isfile(potential_path) else None
